@@ -30,6 +30,34 @@ class CLIContext(TransformAuth):
         super().__init__()
         self.mql = MQLClient(use_async=True)
 
+    @property
+    def is_authenticated(self) -> bool:  # noqa: D
+        if self.api_key is not None or self.bearer_token is not None:
+            try:
+                self.user_state  # Will error if not authed with correct method
+                return True
+            except Exception:
+                return False
+        return False
+
+    def identify(self) -> None:  # noqa: D
+        msg = f"You are authenticated as {self.user_state.user.user_name} within the {self.user_state.organization.name} organization"
+
+        if self.user_state.current_model:
+            msg = (
+                msg
+                + f" using model at {self.user_state.current_model.repository}/{self.user_state.current_model.branch}:{self.user_state.current_model.commit}\n"
+                + self.mql_server_url_status
+            )
+        else:
+            msg = (
+                msg
+                + ". There are currently no metrics committed for your org, please see https://app.transformdata.io/install "
+                + "for instructions on how to commit your first Transform metrics."
+            )
+
+        click.echo(msg)
+
     @property
     def api_key(self) -> Optional[str]:  # noqa: D
         return super().api_key
@@ -63,9 +91,10 @@ class CLIContext(TransformAuth):
 
         return token
 
-    @TransformAuth.bearer_token.setter
+    @bearer_token.setter
     def bearer_token(self, bearer_token: str) -> None:  # noqa: D
-        TransformAuth.bearer_token.fset(self, bearer_token)  # type: ignore
+        self.config._set_config_value(BEARER_TOKEN_CONFIG_KEY, bearer_token)
+        self.config._remove_config_value(API_KEY_CONFIG_KEY)
         self.identify()
         self.__just_authenticated = True
         if self.bearer_token_expires_at is not None:
@@ -74,16 +103,6 @@ class CLIContext(TransformAuth):
                 f"✨ Success! We've set your Transform authorization credentials. Please note that these credentials will expire in {expires_in_hours} hours. We're ready to query.\n"
             )
 
-    @property
-    def is_authenticated(self) -> bool:  # noqa: D
-        if self.api_key is not None or self.bearer_token is not None:
-            try:
-                self.user_state  # Will error if not authed with correct method
-                return True
-            except Exception:
-                return False
-        return False
-
     @property
     def just_authenticated(self) -> bool:
         """Check if the user authenticated on this request. Used for determining if auth override should be prompted."""
@@ -271,24 +290,6 @@ class CLIContext(TransformAuth):
         else:
             return None
 
-    def identify(self) -> None:  # noqa: D
-        msg = f"You are authenticated as {self.user_state.user.user_name} within the {self.user_state.organization.name} organization"
-
-        if self.user_state.current_model:
-            msg = (
-                msg
-                + f" using model at {self.user_state.current_model.repository}/{self.user_state.current_model.branch}:{self.user_state.current_model.commit}\n"
-                + self.mql_server_url_status
-            )
-        else:
-            msg = (
-                msg
-                + ". There are currently no metrics committed for your org, please see https://app.transformdata.io/install "
-                + "for instructions on how to commit your first Transform metrics."
-            )
-
-        click.echo(msg)
-
     @property
     def mql_server_url_config_override(self) -> Optional[str]:  # noqa: D
         return super().mql_server_url_config_override
