@@ -10,10 +10,10 @@ import textwrap
 
 from typing import List, Dict, Optional, Tuple, Any
 
-from gql import Client, gql
-from gql.transport.aiohttp import AIOHTTPTransport
-from gql.transport.requests import RequestsHTTPTransport
-from gql.client import DocumentNode
+from transform.vendor.gql import Client, gql
+from transform.vendor.gql.transport.aiohttp import AIOHTTPTransport
+from transform.vendor.gql.transport.requests import RequestsHTTPTransport
+from transform.vendor.gql.client import DocumentNode
 
 from transform_tools.validate import (
     validate_configs as tt_validate_configs,
