@@ -179,7 +179,7 @@ class MQLClient:
         """Returns a dictionary {metric_name: Metric}."""
         model_key = self.get_model_key(model_key_id) if model_key_id else None
         metrics = {m.name: m for m in self.context.mql_client.get_metrics(model_key)}
-        metrics_metadata = self.context.backend_client.get_metrics_metadata()
+        metrics_metadata = self.context.backend_client.get_metrics_metadata(model_key_id=model_key_id)
         for data in metrics_metadata:
             metrics[data["name"]].input_metadata(data)
         return metrics
@@ -188,7 +188,9 @@ class MQLClient:
         """Retrieve a Metric Object by name."""
         model_key = self.get_model_key(model_key_id) if model_key_id else None
         metric = self.context.mql_client.get_metric_by_name(metric_name, model_key=model_key)
-        metric.input_metadata(self.context.backend_client.get_metric_metadata_by_name(metric_name))
+        metric.input_metadata(
+            self.context.backend_client.get_metric_metadata_by_name(metric_name, model_key_id=model_key_id)
+        )
         return metric
 
     def create_materialization(  # noqa: D
@@ -354,12 +356,12 @@ class MQLClient:
 
     def list_dimensions(
         self,
-        model_key_id: Optional[int] = None,
         metric_names: Optional[List[str]] = None,
+        model_key_id: Optional[int] = None,
     ) -> Dict[str, Dimension]:
         """Retrieves a list of all Dimension objects."""
         model_key = self.get_model_key(model_key_id) if model_key_id else None
-        dimensions = self.context.mql_client.get_dimensions(model_key, metric_names)
+        dimensions = self.context.mql_client.get_dimensions(metric_names, model_key)
         return {dim.name: dim for dim in dimensions}
 
     def get_data_warehouse_issues(self, type: DWValidationType, model_key_id: Optional[int] = None) -> List[str]:
