@@ -6,8 +6,6 @@ import hashlib
 from typing import Tuple
 
 LOCAL = "local"
-DEFAULT_QUERY_TIMEOUT = 180
-POLL_INTERVAL = 1.0
 
 
 def is_git_repo(path: str = None) -> bool:
@@ -39,3 +37,15 @@ def local_commit_info() -> Tuple[str, str, str]:
     hasher.update(str(time.time()).encode("utf-8"))
     commit = str(hasher.hexdigest())
     return LOCAL, LOCAL, commit
+
+
+def resolve_local_commit_info(config_dir: str) -> Tuple[str, str, str]:
+    """Includes logic for uploading Transform models via the CLI."""
+    if is_git_repo(config_dir):
+        repo, branch, commit = get_git_info(config_dir)
+    else:
+        repo, branch, commit = local_commit_info()
+
+    # to differentiate between CI-based commits and local CLI-based commits we edit the commit sha
+    commit += f"-dirty-{int(time.time())}"
+    return repo, branch, commit
